CacheEntry

Struct CacheEntry 

pub struct CacheEntry { /* private fields */ }
A cache entry consisting of a result map for enhanced generation of the next k set and the follow set for a given k

Implementations

Source

impl CacheEntry

pub fn is_empty(&self) -> bool

If this method returns true, the follow set is empty. This is used for the follow cache to indicate that the follow set is not yet calculated.