ParolParserError

Enum ParolParserError 

pub enum ParolParserError {
    UnknownScanner {
        context: String,
        name: String,
        input: PathBuf,
        token: Location,
    },
    EmptyGroup {
        context: String,
        input: PathBuf,
        start: Location,
        end: Location,
    },
    EmptyOptional {
        context: String,
        input: PathBuf,
        start: Location,
        end: Location,
    },
    EmptyRepetition {
        context: String,
        input: PathBuf,
        start: Location,
        end: Location,
    },
    ConflictingTokenAliases {
        first_alias: String,
        second_alias: String,
        expanded: String,
        input: PathBuf,
        first: Location,
        second: Location,
    },
    EmptyScanners {
        empty_scanners: Vec<String>,
    },
    UnsupportedGrammarType {
        grammar_type: String,
        input: PathBuf,
        token: Location,
    },
    UnsupportedFeature {
        feature: String,
        hint: String,
        input: PathBuf,
        token: Location,
    },
    InvalidTokenInTransition {
        context: String,
        token: String,
        input: PathBuf,
        location: Location,
    },
    TokenIsNotInScanner {
        context: String,
        scanner: String,
        token: String,
        input: PathBuf,
        location: Location,
    },
    MixedScannerSwitching {
        context: String,
        input: PathBuf,
        location: Location,
    },
}
Error types used by the crate::parser::ParolGrammar’s semantic actions

Variants



UnknownScanner

Undeclared scanner found. Please declare a scanner via %scanner name {{…}}

Fields

context: String

Context (semantic action) where the error was issued

name: String

Name of the unknown scanner state

input: PathBuf

token: Location

Location



EmptyGroup

Empty Groups () are not allowed.

Fields

context: String

Context (semantic action) where the error was issued

input: PathBuf

start: Location

Start location

end: Location

End location



EmptyOptional

Empty Optionals [] are not allowed.

Fields

context: String

Context (semantic action) where the error was issued

input: PathBuf

start: Location

Start location

end: Location

End location



EmptyRepetition

Empty Repetitions {{}} are not allowed.

Fields

context: String

Context (semantic action) where the error was issued

input: PathBuf

start: Location

Start location

end: Location

End location



ConflictingTokenAliases

Multiple token aliases that expand to the same text will produce a terminal conflict.

Fields

first_alias: String

First

second_alias: String

Second

expanded: String

Expanded

input: PathBuf

first: Location

First alias

second: Location

Second alias



EmptyScanners

Empty Scanner states are not allowed.

Fields

empty_scanners: Vec<String>

Names of the empty scanner states



UnsupportedGrammarType

Unsupported grammar type

Fields

grammar_type: String

The grammar type found

input: PathBuf

token: Location

Location



UnsupportedFeature

Unsupported feature

Fields

feature: String

The feature found

hint: String

Hint

input: PathBuf

token: Location

Location



InvalidTokenInTransition

Invalid token in transition, e.g. a token that is not defined in the grammar is used in a transition. Use a primary non-terminal for the token.

Fields

context: String

Context where the error was issued

token: String

Token that is not defined matched against a valid primary non-terminal

input: PathBuf

Source file

location: Location

Location of the token



TokenIsNotInScanner

The token that is used to initiate a transition is not defined in this scanner.

Fields

context: String

Context where the error was issued

scanner: String

The scanner where the token is not defined

token: String

Token that is not defined in the scanner

input: PathBuf

Source file

location: Location

Location of the token



MixedScannerSwitching

👎Deprecated since 4.0.0:

Scanner switching directives have been removed from the grammar syntax.

Mixed scanner switching is not allowed - use either parser-based or scanner-based switching. Parser-based switching is done via the %sc, %push and %pop directives productions. Scanner-based switching is done via the %on directive in the header of the grammar file.

This error can no more occur as of Parol 4, because scanner switching directives have been removed from the grammar syntax.

Fields

context: String
👎Deprecated since 4.0.0:

Scanner switching directives have been removed from the grammar syntax.

Context where the error was issued

input: PathBuf
👎Deprecated since 4.0.0:

Scanner switching directives have been removed from the grammar syntax.

Source file

location: Location
👎Deprecated since 4.0.0:

Scanner switching directives have been removed from the grammar syntax.

Location of the token